import { parsePercent } from "../../style/utils/parse";
import { overrides } from "../decorators/overrides";
import { view } from "../decorators/view";
import { ViewBase } from "../view/view-base";
let SplitViewItem = class SplitViewItem extends ViewBase {
    constructor() {
        super(...arguments);
        this.nativeView = undefined;
        /**
         * This is the root of flexbox layout.
         */
        this.isRoot = true;
    }
    initNativeView() {
        this.viewController = NSViewController.alloc().init();
        this.splitViewItem = NSSplitViewItem.splitViewItemWithViewController(this.viewController);
        this.nativeView = this.viewController.view;
        return this.nativeView;
    }
    adjustSize() {
        if (this.viewController) {
            const { width, height } = this.viewController.view?.superview?.frame
                .size || { width: 0, height: 0 };
            this.style.width = width;
            this.style.height = height;
        }
    }
    setWidth(key, value, config) {
        const width = this.getValue("width", value);
        config.setNative(this.style, key, width, config);
    }
    setHeight(key, value, config) {
        const height = this.getValue("height", value);
        config.setNative(this.style, key, height, config);
    }
    setMinWidth(_key, value, _config) {
        // config.setNative(this.style, key, value, config);
        // if (this.nativeView) {
        //   this.nativeView.widthAnchor.constraintGreaterThanOrEqualToConstant(
        //     this.getValue("width", value)
        //   ).isActive = true;
        // }
        if (this.splitViewItem) {
            this.splitViewItem.minimumThickness = this.getValue("width", value);
        }
    }
    setMaxWidth(_key, value, _config) {
        // config.setNative(this.style, key, value, config);
        // if (this.nativeView) {
        //   this.nativeView.widthAnchor.constraintLessThanOrEqualToConstant(
        //     this.getValue("width", value),
        //   ).isActive = true;
        //   this.adjustSize();
        // }
        if (this.splitViewItem) {
            this.splitViewItem.maximumThickness = this.getValue("width", value);
        }
    }
    setMinHeight(_key, value, _config) {
        // config.setNative(this.style, key, value, config);
        if (this.nativeView) {
            this.nativeView.heightAnchor.constraintGreaterThanOrEqualToConstant(this.getValue("height", value)).isActive = true;
        }
    }
    setMaxHeight(_key, value, _config) {
        // config.setNative(this.style, key, value, config);
        if (this.nativeView) {
            this.nativeView.heightAnchor.constraintLessThanOrEqualToConstant(this.getValue("height", value)).isActive = true;
            this.adjustSize();
        }
    }
    getValue(type, value) {
        if (typeof value === "number")
            return value;
        if (value?.endsWith("%")) {
            const parentWidth = this.getParentDimension(type);
            const percentValue = parsePercent(value);
            return (parentWidth * percentValue) / 100;
        }
        return this.nativeView?.superview?.frame?.size[type] || 0;
    }
    getParentDimension(type) {
        return (this.parentNode.nativeView?.frame.size[type] ||
            NativeScriptApplication.window.nativeView?.frame.size[type] || 0);
    }
};
__decorate([
    overrides("width"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setWidth", null);
__decorate([
    overrides("height"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setHeight", null);
__decorate([
    overrides("minWidth"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setMinWidth", null);
__decorate([
    overrides("maxWidth"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setMaxWidth", null);
__decorate([
    overrides("minHeight"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setMinHeight", null);
__decorate([
    overrides("maxHeight"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", void 0)
], SplitViewItem.prototype, "setMaxHeight", null);
SplitViewItem = __decorate([
    view({
        name: "HTMLSplitViewItemElement",
        tagName: "split-view-item",
    })
], SplitViewItem);
export { SplitViewItem };
//# sourceMappingURL=split-view-item.js.map