var _a;
import { Layout } from "../../layout/index";
import { overrides } from "../decorators/overrides";
import { view } from "../decorators/view";
import { TextBase } from "./text-base";
class PaddingTextFieldCell extends NSTextFieldCell {
    constructor() {
        super(...arguments);
        this.paddingTop = 0;
        this.paddingLeft = 0;
        this.paddingBottom = 0;
        this.paddingRight = 0;
    }
    cellSizeForBounds(forBounds) {
        const size = super.cellSizeForBounds(forBounds);
        size.height += this.paddingTop + this.paddingBottom;
        size.width += this.paddingLeft + this.paddingRight;
        return size;
    }
    titleRectForBounds(forBounds) {
        const rect = super.titleRectForBounds(forBounds);
        return CGRectInset(rect, this.paddingLeft, this.paddingTop);
    }
    editWithFrameInViewEditorDelegateEvent(rect, controlView, textObj, delegate, event) {
        const insetRect = CGRectInset(rect, this.paddingLeft, this.paddingTop);
        super.editWithFrameInViewEditorDelegateEvent(insetRect, controlView, textObj, delegate, event);
    }
    selectWithFrameInViewEditorDelegateStartLength(rect, controlView, textObj, delegate, selStart, selLength) {
        const insetRect = CGRectInset(rect, this.paddingLeft, this.paddingTop);
        super.selectWithFrameInViewEditorDelegateStartLength(insetRect, controlView, textObj, delegate, selStart, selLength);
    }
    drawInteriorWithFrameInView(cellFrame, controlView) {
        const insetRect = CGRectInset(cellFrame, this.paddingLeft, this.paddingTop);
        super.drawInteriorWithFrameInView(insetRect, controlView);
    }
}
_a = PaddingTextFieldCell;
(() => {
    NativeClass(_a);
})();
let Text = class Text extends TextBase {
    initNativeView() {
        this.nativeView = NSTextField.new();
        this.nativeCell = PaddingTextFieldCell.new();
        this.nativeView.cell = this.nativeCell;
        return this.nativeView;
    }
    prepareNativeView(nativeView) {
        nativeView.isEditable = false;
        // nativeView.isSelectable = false;
        nativeView.drawsBackground = false;
        nativeView.isBordered = false;
    }
    updateTextContent() {
        if (this.nativeView) {
            this.nativeView.stringValue = this.textContent || "";
            Layout.computeAndLayout(this);
        }
    }
    connectedCallback() {
        super.connectedCallback();
        this.updateTextContent();
    }
    setPadding(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingTop = value;
            this.nativeCell.paddingRight = value;
            this.nativeCell.paddingBottom = value;
            this.nativeCell.paddingLeft = value;
        }
    }
    setPaddingTop(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingTop = value;
        }
        Layout.Setters.paddingTop(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingRight(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingRight = value;
        }
        Layout.Setters.paddingRight(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingBottom(_key, value = 0, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingBottom = value;
        }
        Layout.Setters.paddingBottom(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
    setPaddingLeft(_key, value, _config) {
        if (this.nativeCell) {
            this.nativeCell.paddingLeft = value;
        }
        Layout.Setters.paddingLeft(this.yogaNode, value);
        Layout.computeAndLayout(this);
    }
};
__decorate([
    overrides("padding"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPadding", null);
__decorate([
    overrides("paddingTop"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingTop", null);
__decorate([
    overrides("paddingRight"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingRight", null);
__decorate([
    overrides("paddingBottom"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingBottom", null);
__decorate([
    overrides("paddingLeft"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Number, Object]),
    __metadata("design:returntype", void 0)
], Text.prototype, "setPaddingLeft", null);
Text = __decorate([
    view({
        name: "HTMLTextElement",
        tagName: "text",
    })
], Text);
export { Text };
//# sourceMappingURL=text.js.map